# pepNmemb

*pepNmemb* allows you to analyse the interactions of peptides with bacterial membranes from molecular dynamics simulations.

Current functionalities:
- calculate peptide insertion into the membrane over time
- hydrogen bonds with the membrane and other peptides
- inter-peptide interactions
- peptide tilt angle
- membrane lipid apl

